@@ -1,11 +1,12 @@
 use solana_program::{
-    account_info::AccountInfo, entrypoint::ProgramResult, program_error::ProgramError,
+    account_info::AccountInfo, entrypoint::ProgramResult, msg, program_error::ProgramError,
     pubkey::Pubkey,
 };
 
 // Safety verification functions
 pub fn check_account_key(account: &AccountInfo, key: &Pubkey) -> ProgramResult {
     if account.key != key {
+        msg!("Wrong account key: {} should be {}", account.key, key);
         return Err(ProgramError::InvalidArgument);
     }
     Ok(())
@@ -13,6 +14,7 @@ pub fn check_account_key(account: &AccountInfo, key: &Pubkey) -> ProgramResult {
 
 pub fn check_account_owner(account: &AccountInfo, owner: &Pubkey) -> ProgramResult {
     if account.owner != owner {
+        msg!("Wrong account owner: {} should be {}", account.owner, owner);
         return Err(ProgramError::InvalidArgument);
     }
     Ok(())
@@ -20,6 +22,7 @@ pub fn check_account_owner(account: &AccountInfo, owner: &Pubkey) -> ProgramResu
 
 pub fn check_signer(account: &AccountInfo) -> ProgramResult {
     if !(account.is_signer) {
+        msg!("Missing signature for: {}", account.key);
         return Err(ProgramError::MissingRequiredSignature);
     }
     Ok(())
